aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Pipping <sebastian@pipping.org>2011-01-20 15:39:31 +0100
committerSebastian Pipping <sebastian@pipping.org>2011-01-20 15:39:31 +0100
commit901be4dec29197200fa7d6892a4542e1c45f3d1e (patch)
tree1319117b8527ab27795d4d51ce9dfdbc037a0aff
parentRemove unused function bind_mount_dev() (diff)
parentBump version to 3.4.11.1 (diff)
downloadgenkernel-901be4dec29197200fa7d6892a4542e1c45f3d1e.tar.gz
genkernel-901be4dec29197200fa7d6892a4542e1c45f3d1e.tar.bz2
genkernel-901be4dec29197200fa7d6892a4542e1c45f3d1e.zip
Merge branch 'master' into experimental
Conflicts: ChangeLog
-rw-r--r--ChangeLog16
-rwxr-xr-xgen_configkernel.sh25
-rwxr-xr-xgenkernel2
-rw-r--r--patches/busybox/1.18.1/1.18.1-mdstart.diff11
4 files changed, 43 insertions, 11 deletions
diff --git a/ChangeLog b/ChangeLog
index 6f887d3..1a0a907 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -5,13 +5,27 @@
# Distributed under the GPL v2
# $Id$
- 17 Jan 2011; Sebastian Pipping <sping@gentoo.org> ChangeLog:
+ 20 Jan 2011; Sebastian Pipping <sping@gentoo.org> ChangeLog:
Add proper mdadm support (bug #282100)
Special thanks:
- Laurent Pinchart (mdmon/IMSM support)
- Matthias Dahl (Initial patch)
+ 20 Jan 2011; Sebastian Pipping <sping@gentoo.org> genkernel:
+ Bump version to 3.4.11.1
+
+ 20 Jan 2011; Sebastian Pipping <sping@gentoo.org> gen_configkernel.sh:
+ Move application of kernel config after "make mrproper" as that deletes
+ .config (whereas "make clean" does not) (bug #351906)
+
+ Special thanks:
+ - Xake
+
+ 20 Jan 2011; Sebastian Pipping <sping@gentoo.org>
+ patches/busybox/1.18.1/1.18.1-mdstart.diff:
+ busybox 1.18.1: Return of mdstart as an applet (regression) (bug #351909)
+
16 Jan 2011; Sebastian Pipping <sping@gentoo.org> genkernel:
Bump version to 3.4.11
diff --git a/genkernel b/genkernel
index a3f1336..6a3351f 100755
--- a/genkernel
+++ b/genkernel
@@ -2,7 +2,7 @@
# $Id$
PATH="${PATH}:/sbin:/usr/sbin"
-GK_V='3.4.11'
+GK_V='3.4.11.1'
# Set the default for TMPDIR. May be modified by genkernel.conf or the
# --tempdir command line option.
diff --git a/patches/busybox/1.18.1/1.18.1-mdstart.diff b/patches/busybox/1.18.1/1.18.1-mdstart.diff
index 88be233..6e4bf3f 100644
--- a/patches/busybox/1.18.1/1.18.1-mdstart.diff
+++ b/patches/busybox/1.18.1/1.18.1-mdstart.diff
@@ -3,6 +3,17 @@ Based on:
> Forward-port the old mdstart tool from the Gentoo Busybox-1.1.3.
> Only fires the RAID_AUTORUN ioctl on existing /dev/md nodes.
+diff -pruN a/include/applets.src.h mdstart/include/applets.src.h
+--- a/include/applets.src.h 2011-01-20 01:08:05.470632138 +0100
++++ mdstart/include/applets.src.h 2011-01-20 01:09:13.198003320 +0100
+@@ -235,6 +235,7 @@ IF_MAN(APPLET(man, _BB_DIR_SBIN, _BB_SUI
+ IF_MATCHPATHCON(APPLET(matchpathcon, _BB_DIR_USR_SBIN, _BB_SUID_DROP))
+ IF_MD5SUM(APPLET_NOEXEC(md5sum, md5_sha1_sum, _BB_DIR_USR_BIN, _BB_SUID_DROP, md5sum))
+ IF_MDEV(APPLET(mdev, _BB_DIR_SBIN, _BB_SUID_DROP))
++IF_MDSTART(APPLET(mdstart, _BB_DIR_SBIN, _BB_SUID_DROP))
+ IF_MICROCOM(APPLET(microcom, _BB_DIR_USR_BIN, _BB_SUID_DROP))
+ IF_MKDIR(APPLET_NOFORK(mkdir, mkdir, _BB_DIR_BIN, _BB_SUID_DROP, mkdir))
+ IF_MKFS_VFAT(APPLET_ODDNAME(mkdosfs, mkfs_vfat, _BB_DIR_SBIN, _BB_SUID_DROP, mkfs_vfat))
diff -pruN a/include/usage.src.h mdstart/include/usage.src.h
--- a/include/usage.src.h 2010-12-21 06:29:45.000000000 +0200
+++ mdstart/include/usage.src.h 2011-01-12 21:29:47.000000000 +0200
diff --git a/gen_configkernel.sh b/gen_configkernel.sh
index 990975c..2e0737f 100755
--- a/gen_configkernel.sh
+++ b/gen_configkernel.sh
@@ -30,10 +30,10 @@ config_kernel() {
determine_config_file
cd "${KERNEL_DIR}" || gen_die 'Could not switch to the kernel directory!'
- # Backup and replace kernel .config
- if isTrue "${CLEAN}" || [ ! -f "${KERNEL_DIR}/.config" ]
+ # Backup current kernel .config
+ if isTrue "${MRPROPER}" || [ ! -f "${KERNEL_DIR}/.config" ]
then
- print_info 1 "config: Using config from ${KERNEL_CONFIG}"
+ print_info 1 "kernel: Using config from ${KERNEL_CONFIG}"
if [ -f "${KERNEL_DIR}/.config" ]
then
NOW=`date +--%Y-%m-%d--%H-%M-%S`
@@ -41,39 +41,46 @@ config_kernel() {
|| gen_die "Could not backup kernel config (${KERNEL_DIR}/.config)"
print_info 1 " Previous config backed up to .config${NOW}.bak"
fi
- cp "${KERNEL_CONFIG}" "${KERNEL_DIR}/.config" || gen_die 'Could not copy configuration file!'
fi
if isTrue ${MRPROPER}
then
print_info 1 'kernel: >> Running mrproper...'
compile_generic mrproper kernel
+ else
+ print_info 1 "kernel: --mrproper is disabled; not running 'make mrproper'."
fi
# If we're not cleaning, then we don't want to try to overwrite the configs
# or we might remove configurations someone is trying to test.
+ if isTrue "${MRPROPER}" || [ ! -f "${KERNEL_DIR}/.config" ]
+ then
+ cp "${KERNEL_CONFIG}" "${KERNEL_DIR}/.config" || gen_die 'Could not copy configuration file!'
+ fi
if isTrue "${OLDCONFIG}"
then
print_info 1 ' >> Running oldconfig...'
yes '' 2>/dev/null | compile_generic oldconfig kernel 2>/dev/null
+ else
+ print_info 1 "kernel: --oldconfig is disabled; not running 'make oldconfig'."
fi
if isTrue "${CLEAN}"
then
print_info 1 'kernel: >> Cleaning...'
compile_generic clean kernel
else
- print_info 1 "config: --no-clean is enabled; not running 'make clean'."
+ print_info 1 "kernel: --clean is disabled; not running 'make clean'."
fi
if isTrue ${MENUCONFIG}
then
- print_info 1 'config: >> Invoking menuconfig...'
+ print_info 1 'kernel: >> Invoking menuconfig...'
compile_generic menuconfig runtask
[ "$?" ] || gen_die 'Error: menuconfig failed!'
elif isTrue ${CMD_GCONFIG}
then
- print_info 1 'config: >> Invoking gconfig...'
+ print_info 1 'kernel: >> Invoking gconfig...'
compile_generic gconfig kernel
[ "$?" ] || gen_die 'Error: gconfig failed!'
@@ -82,7 +89,7 @@ config_kernel() {
if isTrue ${CMD_XCONFIG}
then
- print_info 1 'config: >> Invoking xconfig...'
+ print_info 1 'kernel: >> Invoking xconfig...'
compile_generic xconfig kernel
[ "$?" ] || gen_die 'Error: xconfig failed!'
fi
@@ -41,39 +41,46 @@ config_kernel() {
fi
- # If we're not cleaning, then we don't want to try to overwrite the configs
+ # If we're not cleaning a la mrproper, then we don't want to try to overwrite the configs
# or we might remove configurations someone is trying to test.